pub struct PeriodMidpointTracker { /* private fields */ }Expand description
Tracks period open/high/low/close on a configurable Timeframe and yields the prior
(confirmed) period’s midpoint once a new period starts.
Implementations
Sourceimpl PeriodMidpointTracker
impl PeriodMidpointTracker
pub fn new(period_tf: Timeframe) -> Result<Self, TimeframeError>
pub fn with_utc_offset( period_tf: Timeframe, utc_offset_seconds: i32, ) -> Result<Self, TimeframeError>
pub fn reset(&mut self)
Sourcepub fn on_bar(&mut self, bar: &Bar) -> Option<PriceLevel>
pub fn on_bar(&mut self, bar: &Bar) -> Option<PriceLevel>
Returns Some(midpoint) only on the bar that closes a period (the same “confirmed value
becomes available one bar later” convention as crate::timeframe::BarResampler).