SeriesEvents

Struct SeriesEvents 

pub struct SeriesEvents;
Helper functions for time series calculations and crossovers.

Implementations

Source

impl SeriesEvents

pub fn change(series: &Series<f64>) -> Option<f64>

Returns difference series[0] - series[1].

pub fn rising(series: &Series<f64>, length: usize) -> bool

Returns true if the series has been strictly increasing over the last length bars.

pub fn falling(series: &Series<f64>, length: usize) -> bool

Returns true if the series has been strictly decreasing over the last length bars.

pub fn cross(a: &Series<f64>, b: &Series<f64>) -> bool

Returns true if series a crossed series b in either direction on the latest bar.

pub fn crossover(a: &Series<f64>, b: &Series<f64>) -> bool

Returns true if series a crossed above series b (a[1] <= b[1] and a[0] > b[0]).

pub fn crossunder(a: &Series<f64>, b: &Series<f64>) -> bool

Returns true if series a crossed below series b (a[1] >= b[1] and a[0] < b[0]).

pub fn cum(series: &Series<f64>) -> f64

Returns the sum of all finite values in series.

pub fn value_when<'a, T>( condition: &Series<bool>, source: &'a Series<T>, occurrence: usize, ) -> Option<&'a T>

Returns the source value at the requested occurrence of a separate condition series.