Rolling statistical primitives, linear regression, and sample statistics (Wilson interval, longest run). Rolling statistics primitives for streaming series calculations.
Structs
- Linear
Regression Result - Result of a linear regression fit over a data slice.
- Proportion
Interval - A binomial proportion with its confidence bounds, all in
0.0..=1.0.
Functions
- correlation
- Computes Pearson correlation from finite, positionally aligned pairs.
- linear_
regression - Computes ordinary least squares (OLS) linear regression over a slice of values (where X is 0..N-1).
- longest_
run - Length of the longest unbroken run of consecutive elements for which
predicateholds;0if it never does. - percent_
rank - Returns the percentile rank (0.0..=100.0) of
valwithinslice. - rolling_
mean - Returns the arithmetic mean of all finite values in
slice. - rolling_
median - Returns the median of finite values in
slice. - rolling_
quantile - Returns the quantile (0.0..=1.0) of finite values in
slice. - rolling_
stddev - Returns the standard deviation of finite values in
slice. - rolling_
sum - Returns the sum of all finite values in
slice. - rolling_
variance - Returns the population variance of finite values in
slice. - wilson_
interval - Wilson score interval for
successesout oftrials.